import re
import datetime

WHITE = '\033[97m'
CYAN = '\033[96m'
HEADER = '\033[95m'
OKBLUE = '\033[94m'
OKGREEN = '\033[92m'
WARNING = '\033[93m'
FAIL = '\033[91m'
ENDC = '\033[0m'
BOLD = '\033[1m'
UNDERLINE = '\033[4m'


class LogFormatter:
    def _format(self, text: str = "", severity: str = "", prefix: str = "") -> str:
        # Timestamp, Severity, prefix, message
        if not self.do_colors():
            text = self.strip_color(text)

        meta = ""
        if self.do_timestamps():
            meta += str(datetime.datetime.now().isoformat()) + " "

        if self.do_severity() and len(severity) > 0:
            meta += "[" + severity.upper() + "] "

        if self.do_prefix() and len(prefix) > 0:
            meta += prefix + ": "

        if self.do_colors():
            return WHITE + meta + text + ENDC
        return meta + text

    def do_timestamps(self) -> bool:
        return False

    def do_colors(self) -> bool:
        return False

    def do_prefix(self) -> bool:
        return True

    def do_severity(self) -> bool:
        return True

    def strip_color(self, text):
        ansi_escape = re.compile(r'\x1B\[[0-?]*[ -/]*[@-~]')
        return ansi_escape.sub('', text)



from __future__ import annotations
import random
import string


class Logger:
    def __init__(self, prefix: str = None, debug_mode: int = 0):
        self.prefix: str = prefix
        self._chosen_prefix: bool = True
        if not self.prefix:
            self.prefix = self.random_chars(3)
            self._chosen_prefix: bool = False

        self.debug_mode: int = debug_mode

    def random_chars(self, length: int):
        return ''.join(random.choices(string.ascii_uppercase + string.digits, k=length))

    def _output(self, message: str):
        print(self.prefix + " " + message, flush=True)

    def info(self, message: str = ""):
        self._output("[INFO] " + str(message))

    def warning(self, message: str = ""):
        self._output("[WARNING] " + str(message))

    def severe(self, message: str = ""):
        self._output("[SEVERE] " + str(message))

    def newline(self):
        self._output("")

    def debug(self, message: str = "", force: bool = False):
<<<<<<< HEAD
        if self.debug_mode > 0 or force:
            self._output("[DEBUG] " + message)

    def debugg(self, message: str = "", force: bool = False):
        if self.debug_mode > 1 or force:
            self._output("[DEBUG] " + message)

    def debuggg(self, message: str = "", force: bool = False):
        if self.debug_mode > 2 or force:
            self._output("[DEBUG] " + message)
=======
        if self.debug_mode or force:
            self._output("[DEBUG] " + str(message))
>>>>>>> ffc702866f6160e6d5a507c482c59725605d084b

    def spinoff(self, prefix: str = None) -> Logger:
        if prefix:
            prefix = self.prefix + "-" + prefix
        else:
            prefix = self.prefix + "-" + self.random_chars(3)
        return Logger(prefix=prefix, debug_mode=self.debug_mode)



from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='ehelply-logger',
    packages=find_packages(),
    version='0.0.5',
    description='Logger.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Shawn Clake',
    author_email='shawn.clake@gmail.com',
    url='https://github.com/ehelply/Logger',
    keywords=['logger'],
    include_package_data=True,
    classifiers=(
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
    ),
    install_requires=[
        'pytest'
    ],
)
